﻿'# Title    : SlimDX Particle Effects
'# Author   : Sascha Bajus
'# Created  : 01/2009
'# Copyright © 2009 Sascha Bajus



#Region "Copyright© Information (German)"
' Diese Software wird bereitgestellt "wie sie ist", ohne jegliche ausdrückliche oder 
' stillschweigende Gewährleistung. In keinem Fall kann der Author haftbar gemacht werden
' für Schäden, die aus der Nutzung dieser Software entstanden sind.
'
' Es ist erlaubt, diese Software für jeden Zweck zu nutzen, einschließlich der kommerziellen 
' Anwendungen, und sie zu verändern, vorbehaltlich der folgenden Einschränkungen: 
'
' 1. Der Ursprung dieser Software darf nicht falsch dargestellt werden; Sie dürfen nicht behaupten, 
'    dass Sie der Urheber der Original-Software sind. Wenn Sie diese Software in einem Produkt 

' 2. Altered-Source-Versionen müssen klar als solche gekennzeichnet, und dürfen nicht als 
'    Original-Software dargestellt werden.
'
' 3. Diese Informationen dürfen nicht entfernt oder geändert werden.
#End Region
#Region "Copyright© Information (English)"
' This software is provided 'as-is', without any express or implied warranty. In no event will 
' the authors be held liable for any damages arising from the use of this software.
'
' Permission is granted to anyone to use this software for any purpose, including commercial 
' applications, and to alter it and redistribute it freely, subject to the following restrictions:
'
' 1. The origin of this software must not be misrepresented; you must not claim that you wrote 
'    the original software. If you use this software in a product, an acknowledgment in the 
'    product documentation would be appreciated but is not required.
'
' 2. Altered source versions must be plainly marked as such, and must not be misrepresented 
'    as being the original software.
'
' 3. This notice may not be removed or altered from any source distribution.
'
#End Region



Imports SlimDX
Imports SlimDX.Direct3D9
Imports SlimDX.DirectInput
Imports sdxBaseEngine


Public Class Project : Inherits baseEngine

    Private _text As String = "Press 1 - 0 to change Particle Effect"
    Private _tex(2) As Texture
    Private _rotate As Boolean
    Private _name As String


    Public Sub New()


        AddHandler dxRenderScene, AddressOf render
        AddHandler dxKeyboardState, AddressOf keyboard
        AddHandler dxLoadingProject, AddressOf loading
        '---------------------------------------------

        If dxEngine("SlimDX - BaseEngine -  Particle Effects Demo") = False Then Me.Close()

    End Sub
#Region "Loading"
    Private Sub Loading()


        '#set Cam
        dxCamera.currentPosition = New Vector3(0, 0, -16)
        '#set Backcolor
        dxEngine.TargetBufferColor = Color.Black

        '#load texture resources
        Dim res As New sdxResource("resx_texture.dll")
        _tex(0) = dxTexture.loadTexture(res.loadResource("particle1.png"), Color.Black)
        _tex(1) = dxTexture.loadTexture(res.loadResource("particle2.png"), Color.Black)
        _tex(2) = dxTexture.loadTexture(res.loadResource("particle3.png"), Color.Black)

        '#set blending on
        dxTexture.AlphaBlending3 = True
        '#start set1
        set1()

    End Sub
#End Region
#Region "## render ##"
    Private Sub render()
        '# use rotation if true
        If _rotate Then
            dxTransformWorld = dxMatrix.TimebasedRotationY(0.01, 300)
        Else
            dxTransformWorld = Matrix.Identity
        End If

        '# reder Particle
        dxEffect.ParticleEngine.Draw()
        '# draw FPS
        dx2DText.drawFPS(vbCrLf & _name & vbCrLf & _text)
    End Sub
#End Region
#Region "## keyboard ##"
    Private Sub keyboard()
        With dxEngine

            '#Close App
            If .KeyPressed(Key.Escape) Then Me.Close()

            If .KeyPressed(Key.D1) Then set1() '#Effect set1
            If .KeyPressed(Key.D2) Then set2() '#Effect set2
            If .KeyPressed(Key.D3) Then set3() '#Effect set3
            If .KeyPressed(Key.D4) Then set4() '#Effect set4
            If .KeyPressed(Key.D5) Then set5() '#Effect set5
            If .KeyPressed(Key.D6) Then set6() '#Effect set6
            If .KeyPressed(Key.D7) Then set7() '#Effect set7
            If .KeyPressed(Key.D8) Then set8() '#Effect set8
            If .KeyPressed(Key.D9) Then set9() '#Effect set9
            If .KeyPressed(Key.D0) Then set0() '#Effect set0

        End With
    End Sub
#End Region
#Region "## Exit Application ##"
    Private Sub closeForm() Handles Me.FormClosing
        closeApplication()
    End Sub
    Private Sub closeApplication()
        For i As Integer = 0 To _tex.Length - 1
            If Not _tex(i) Is Nothing Then _tex(i).Dispose()
        Next
        dxEngine.closeBaseEngine()
        End
    End Sub
#End Region


#Region "set1 - Comet"
    Private Sub set1()
        _name = "Effect: - Comet - 200 Particle"
        _rotate = False

        '#ParticleEngine Setup
        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .StartColor = Color.FromArgb(175, 64, 33)
            .ColorFading = True
            .ParticleCount = 200
            .DecreaseLifetime(0.05) = 0.05
            .Emitter = New Vector3(-5, -3, 0)
            .EmitterRandom = New Vector3(0, 0.1, 0)
            .ParticleSize = 0.1
            .Direction = New Vector3(0.5, 0.5, 0)
            .DirectionRandom = New Vector3(0.1, 0.2, 0)
        End With
    End Sub
#End Region
#Region "set2 - Low Flames "
    Private Sub set2()
        _name = "Effect: Low Flames - 200 Particle"
        _rotate = False

        '#ParticleEngine Setup
        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .StartColor = Color.FromArgb(175, 64, 33)
            .ColorFading = True
            .ParticleCount = 200
            .DecreaseLifetime(0.02) = 0.05
            .Emitter = New Vector3(0, -5, 0)
            .EmitterRandom = New Vector3(0, 0.4, 0)
            .ParticleSize = 0.15
            .Direction = New Vector3(0, 0, 0)
            .DirectionRandom = New Vector3(-1.8, 0.4, 0)
            .DirectionBothSides = True
        End With
    End Sub
#End Region
#Region "set3 - Fireplace"
    Private Sub set3()
        _name = "Effect: - Fireplace - 400 Particle"
        _rotate = False

        '#ParticleEngine Setup
        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .StartColor = Color.FromArgb(175, 64, 33)
            .ColorFading = True
            .ParticleCount = 400
            .DecreaseLifetime(0.04) = 0.02
            .Emitter = New Vector3(0, -5, 0)
            .EmitterRandom = New Vector3(2.5, 0, 0)
            .ParticleSize = 0.09
            .Direction(-0.0011) = New Vector3(0, 0.2, 0)
            .DirectionRandom = New Vector3(0.08, 0.1, 0)
            .DirectionBothSides = True
            .RenderSpeed = 450
        End With
    End Sub
#End Region
#Region "set4 - Bubbles"
    Private Sub set4()
        _name = "Effect: - Bubbles - 300 Particle"
        _rotate = False

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(1)
            .StartColor = Color.FromArgb(130, 200, 178)
            .ParticleCount = 300
            .DecreaseLifetime(0.02) = 0.015
            .Emitter = New Vector3(0, -5, 0)
            .EmitterRandom = New Vector3(0, 1.2, 0)
            .ParticleSize = 0.1
            .Direction(6) = New Vector3(0, 0.2, 0)
            .DirectionRandom = New Vector3(0.6, 0.2, 0)
            .DirectionBothSides = True
        End With
    End Sub
#End Region
#Region "set5 - Underwater"
    Private Sub set5()
        _name = "Effect: - Underwater - 200 Particle"
        _rotate = False

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(1)
            .StartColor = Color.FromArgb(133, 155, 255)
            .ColorFading = True
            .ParticleCount = 200
            .DecreaseLifetime(0.01) = 0.01
            .Emitter = New Vector3(7, 0, 0)
            .EmitterRandom = New Vector3(0, 1.5, 0)
            .ParticleSize = 0.1
            .Direction() = New Vector3(-0.1, 0, 0)
            .DirectionRandom = New Vector3(0.15, 0.1, 0)
            .DirectionBothSides = True
            .RenderSpeed = 500
        End With
    End Sub
#End Region
#Region "set6 - Bubble Wall"
    Private Sub set6()
        _name = "Effect: - Bubble Wall - 600 Particle"
        _rotate = True

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(1)
            .StartColor = Color.FromArgb(122, 122, 225)
            .ColorFading = False
            .ParticleCount = 600
            .DecreaseLifetime(0.005) = 0.008
            .Emitter = New Vector3(0, -4, 0)
            .EmitterRandom = New Vector3(12, 0, 3)
            .ParticleSize = 0.1
            .Direction = New Vector3(0, 0.05, 0)
            .DirectionBothSides = True
            .DirectionRandom = New Vector3(0, 0.05, 0)
        End With
    End Sub
#End Region
#Region "set7 - Dust"
    Private Sub set7()
        _name = "Effect: - Dust - 1000 Particle"
        _rotate = True

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .StartColor = Color.FromArgb(255, 155, 155)
            .ParticleCount = 1000
            .DecreaseLifetime(0.1) = 0.005
            .Emitter = New Vector3(0, -5, 0)
            .EmitterRandom = New Vector3(2, 0, 2)
            .ParticleSize = 0.01
            .Direction(-0.0005) = New Vector3(0, 0.05, 0)
            .DirectionRandom = New Vector3(0.2, 0.05, 0.2)
            .DirectionBothSides = True
        End With
    End Sub
#End Region
#Region "set8 - Snow"
    Private Sub set8()
        _name = "Effect: - Snow - 1300 Particle"
        _rotate = False

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .ParticleCount = 1300
            .StartColor = Color.FromArgb(235, 235, 255)
            .RenderSpeed = 8600
            .DecreaseLifetime(0.01) = 0.01
            .Emitter = New Vector3(0, 7, 0)
            .EmitterRandom = New Vector3(10, 0, 0)
            .Direction = New Vector3(0, -1, 0)
            .DirectionRandom = New Vector3(1, -1, 0)
            .DirectionBothSides = True
            .ColorFading = True
            .ParticleSize = 0.015

        End With

    End Sub
#End Region
#Region "set9 - Confetti"
    Private Sub set9()
        _name = "Effect: - Confetti - 3000 Particle"
        _rotate = True

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(0)
            .StartColor = Color.FromArgb(225, 255, 255)
            .ColorRandom = True
            .ParticleCount = 3000
            .DecreaseLifetime(0) = 0.02
            .Emitter = New Vector3(0, 5, 0)
            .EmitterRandom = New Vector3(6, 0, 6)
            .ParticleSize = 0.01
            .Direction = New Vector3(0, -0.5, 0)
            .DirectionRandom = New Vector3(1, 0, 1)
            .DirectionBothSides = True
            .ParticleSize = 0.01
            .RenderSpeed = 1500
            .StopMoving = 0.7
        End With
    End Sub
#End Region
#Region "set0 - Stardust"
    Private Sub set0()
        _name = "Effect: - Stardust - 1000 Particle"
        _rotate = False

        With dxEffect.ParticleEngine
            .resetEngine()
            .Texture = _tex(2)
            .StartColor = Color.FromArgb(115, 225, 155)
            .ColorFading = True
            .ParticleCount = 1000
            .DecreaseLifetime(0.05) = 0.005
            .Emitter = New Vector3(0, 0, 6)
            .Direction = New Vector3(0, 0, -0.9)
            .DirectionRandom = New Vector3(0.2, 0.2, 0)
            .DirectionBothSides = True
            .ParticleSize = 0.024
            .RenderSpeed = 1500
        End With
    End Sub
#End Region
End Class
